#!/usr/bin/perl -w  # -*- cperl -*- #
#
#  pause.pm - Handle the "pause" and "unpause" commands.
#
#  Steve Kemp
#  ---
#  http://www.steve.org.uk/
#
#


#
#  The package this module is implementing.
#
package Xen::Monitor::Plugins::pause;


#
#  Register the plugin.
#
Xen::Monitor::Server::register_plugin("Xen::Monitor::Plugins::pause");



#
#  Minimal constructor.
#
sub new { return bless {}; }



#
#  Return the author of this plugin.
#
sub getAuthor
{
    return( 'Steve Kemp <steve@steve.org.uk>' );
}


#
#  Does this plugin require authentication?
#
sub needsAuth
{
    return 1;
}

#
#  Return the commands we handle.
#
sub getCommand
{
    my %commands;
    $commands{"pause"}	 = 1;
    $commands{"unpause"} = 1;
    return( %commands );
}


#
# Run the command we're sent - this means 'pause' or 'unpause'.
#
sub runCommand
{
    my ( $class, $server, $command, @args ) = ( @_ );

    my $host = shift( @args );

    if ( !defined( $host ) )
    {
	print "400 MISSING HOST\r\n";
	return;
    }

    #
    #  Test to see if the user can execute the given command
    #
    if ( ! $server->canControl( $host ) )
    {
	print "400 NOT ALLOWED\r\n";
	return;
    }

    my $instance = Xen::Host->new( name => $host );

    if ( $command =~ /^pause$/i )
    {
	print "200 OK\r\n";
	$instance->pause();
	print "300 DONE\r\n";
    }
    if ( $command =~ /^unpause$/i )
    {
	print "200 OK\r\n";
	$instance->unpause();
	print "300 DONE\r\n";
    }
}


1;
